==> kubernetes-model-1.0.47-sources.jar: annotations/io/fabric8/kubernetes/api/model/MetadataVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.List;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;

public class MetadataVolumeSourceFluentImpl<T extends MetadataVolumeSourceFluent<T>> extends BaseFluent<T> implements MetadataVolumeSourceFluent<T>{

     List<VisitableBuilder<MetadataFile, ?>> items = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public MetadataVolumeSourceFluentImpl(){
    
}
public MetadataVolumeSourceFluentImpl( MetadataVolumeSource instance ){
    this.withItems(instance.getItems()); 
}

    public T addToItems( MetadataFile ...items){
    for (MetadataFile item : items) {MetadataFileBuilder builder = new MetadataFileBuilder(item);_visitables.add(builder);this.items.add(builder);} return (T)this;
    }
    public T removeFromItems( MetadataFile ...items){
    for (MetadataFile item : items) {MetadataFileBuilder builder = new MetadataFileBuilder(item);_visitables.remove(builder);this.items.remove(builder);} return (T)this;
    }
    public List<MetadataFile> getItems(){
    return build(items);
    }
    public T withItems( List<MetadataFile> items){
    this.items.clear();if (items != null) {for (MetadataFile item : items){this.addToItems(item);}} return (T) this;
    }
    public T withItems( MetadataFile ...items){
    this.items.clear(); if (items != null) {for (MetadataFile item :items){ this.addToItems(item);}} return (T) this;
    }
    public ItemsNested<T> addNewItem(){
    return new ItemsNestedImpl<T>();
    }
    public ItemsNested<T> addNewItemLike( MetadataFile item){
    return new ItemsNestedImpl<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
MetadataVolumeSourceFluentImpl that = (MetadataVolumeSourceFluentImpl) o;
if (items != null ? !items.equals(that.items) :that.items != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class ItemsNestedImpl<N> extends MetadataFileFluentImpl<ItemsNested<N>> implements ItemsNested<N>{

        private final MetadataFileBuilder builder;
    
             ItemsNestedImpl ( MetadataFile item){
        this.builder = new MetadataFileBuilder(this, item);
        }
             ItemsNestedImpl (){
        this.builder = new MetadataFileBuilder(this);
        }
    
            public N endItem(){
            return and();
        }
            public N and(){
            return (N) MetadataVolumeSourceFluentImpl.this.addToItems(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/MetadataVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.List;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;

public class MetadataVolumeSourceFluentImpl<A extends MetadataVolumeSourceFluent<A>> extends BaseFluent<A> implements MetadataVolumeSourceFluent<A>{

     List<VisitableBuilder<MetadataFile, ?>> items = new ArrayList();
public MetadataVolumeSourceFluentImpl(){
    
}
public MetadataVolumeSourceFluentImpl( MetadataVolumeSource instance ){
    this.withItems(instance.getItems()); 
}

    public A addToItems( MetadataFile ...items){
    for (MetadataFile item : items) {MetadataFileBuilder builder = new MetadataFileBuilder(item);_visitables.add(builder);this.items.add(builder);} return (A)this;
    }
    public A removeFromItems( MetadataFile ...items){
    for (MetadataFile item : items) {MetadataFileBuilder builder = new MetadataFileBuilder(item);_visitables.remove(builder);this.items.remove(builder);} return (A)this;
    }
    public List<MetadataFile> getItems(){
    return build(items);
    }
    public A withItems( List<MetadataFile> items){
    this.items.clear();if (items != null) {for (MetadataFile item : items){this.addToItems(item);}} return (A) this;
    }
    public A withItems( MetadataFile ...items){
    this.items.clear(); if (items != null) {for (MetadataFile item :items){ this.addToItems(item);}} return (A) this;
    }
    public ItemsNested<A> addNewItem(){
    return new ItemsNestedImpl();
    }
    public ItemsNested<A> addNewItemLike( MetadataFile item){
    return new ItemsNestedImpl(item);
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
MetadataVolumeSourceFluentImpl that = (MetadataVolumeSourceFluentImpl) o;
if (items != null ? !items.equals(that.items) :that.items != null) return false;
return true;

    }

    public class ItemsNestedImpl<N> extends MetadataFileFluentImpl<ItemsNested<N>> implements ItemsNested<N>{

        private final MetadataFileBuilder builder;
    
             ItemsNestedImpl ( MetadataFile item){
        this.builder = new MetadataFileBuilder(this, item);
        }
             ItemsNestedImpl (){
        this.builder = new MetadataFileBuilder(this);
        }
    
            public N endItem(){
            return and();
        }
            public N and(){
            return (N) MetadataVolumeSourceFluentImpl.this.addToItems(builder.build());
        }
    
}


}
